@@ -103,7 +103,9 @@ class ConditionExpressionTypeDef(
     pass
 
 
-CsvOptionsTypeDef = TypedDict("CsvOptionsTypeDef", {"Delimiter": str}, total=False)
+CsvOptionsTypeDef = TypedDict(
+    "CsvOptionsTypeDef", {"Delimiter": str, "HeaderRow": bool}, total=False
+)
 
 CsvOutputOptionsTypeDef = TypedDict("CsvOutputOptionsTypeDef", {"Delimiter": str}, total=False)
 
@@ -132,6 +134,7 @@ _OptionalDatasetTypeDef = TypedDict(
         "AccountId": str,
         "CreatedBy": str,
         "CreateDate": datetime,
+        "Format": Literal["CSV", "JSON", "PARQUET", "EXCEL"],
         "FormatOptions": "FormatOptionsTypeDef",
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
@@ -148,7 +151,9 @@ class DatasetTypeDef(_RequiredDatasetTypeDef, _OptionalDatasetTypeDef):
 
 
 ExcelOptionsTypeDef = TypedDict(
-    "ExcelOptionsTypeDef", {"SheetNames": List[str], "SheetIndexes": List[int]}, total=False
+    "ExcelOptionsTypeDef",
+    {"SheetNames": List[str], "SheetIndexes": List[int], "HeaderRow": bool},
+    total=False,
 )
 
 FormatOptionsTypeDef = TypedDict(
@@ -444,6 +449,7 @@ _OptionalDescribeDatasetResponseTypeDef = TypedDict(
     {
         "CreatedBy": str,
         "CreateDate": datetime,
+        "Format": Literal["CSV", "JSON", "PARQUET", "EXCEL"],
         "FormatOptions": "FormatOptionsTypeDef",
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
